# Put in a separate page so it can be used by SciMLDocs.jl

pages = [
    "Home" => "index.md",
    "Interfaces" => Any[
        "interfaces/Array_and_Number.md",
        "interfaces/Problems.md",
        "interfaces/SciMLFunctions.md",
        "interfaces/Algorithms.md",
        "interfaces/Solutions.md",
        "interfaces/Init_Solve.md",
        "interfaces/Ensembles.md",
        "interfaces/Common_Keywords.md",
        "interfaces/Differentiation.md",
        "interfaces/PDE.md",
    ],
    "Fundamentals" => Any["fundamentals/FAQ.md"],
]
